==> jc-1.4.0.tar.gz: soot/UnknownMethodSource.c <==
// public class soot.UnknownMethodSource

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 46c999f340ec4a2f soot_MethodSource
// @dep_class bd11c16680505218 soot_SootMethod
// @dep_class c2f8a579c8aaa450 soot_UnknownMethodSource

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_RuntimeException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable
// @dep_header soot_Body
// @dep_header soot_MethodSource
// @dep_header soot_SootMethod
// @dep_header soot_UnknownMethodSource

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/RuntimeException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"
#include "soot/Body.h"
#include "soot/MethodSource.h"
#include "soot/SootMethod.h"
#include "soot/UnknownMethodSource.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_soot_UnknownMethodSource$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_UnknownMethodSource$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_UnknownMethodSource$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_UnknownMethodSource$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_UnknownMethodSource$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_soot_UnknownMethodSource$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_UnknownMethodSource$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_UnknownMethodSource, _init$52f4ad9f2989aeee);

void
_jc_soot_UnknownMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_UnknownMethodSource$object *this)
{
	struct _jc_soot_UnknownMethodSource$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(41);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.Body getBody(soot.SootMethod, java.lang.String)
//

static _jc_linenum _jc_soot_UnknownMethodSource$linenum_table$getBody$01a871f1d690f082[];

static const unsigned char _jc_soot_UnknownMethodSource$param_ptypes$getBody$01a871f1d690f082[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_UnknownMethodSource$param_types$getBody$01a871f1d690f082[] = {
	&_jc_soot_SootMethod$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082 = {
	.name=			"getBody",
	.signature=		"(Lsoot/SootMethod;Ljava/lang/String;)Lsoot/Body;",
	.class=			&_jc_soot_UnknownMethodSource$type,
	.param_types=		&_jc_soot_UnknownMethodSource$param_types$getBody$01a871f1d690f082,
	.return_type=		&_jc_soot_Body$type,
	.param_ptypes=		&_jc_soot_UnknownMethodSource$param_ptypes$getBody$01a871f1d690f082,
	.signature_hash=	_JC_JLONG(0x1a871f1d690f082),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_UnknownMethodSource$vtable, soot_UnknownMethodSource.getBody$01a871f1d690f082) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_UnknownMethodSource$linenum_table$getBody$01a871f1d690f082
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_UnknownMethodSource, getBody$01a871f1d690f082);

_jc_soot_Body$object *
_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082(_jc_env *const env, _jc_soot_UnknownMethodSource$object *this, _jc_soot_SootMethod$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_soot_UnknownMethodSource$object *r0;
	struct _jc_soot_SootMethod$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_RuntimeException$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_VMThrowable$object *r6;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(51);				// 0
	r3 = _JC_NEW(env, java_lang_RuntimeException);
	r4 = _JC_STRING(env, "Can't get body for unknown source!");
	_JC_REF_FIELD(env, r3, java_lang_Throwable, cause) = r3;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r3);
	_JC_REF_FIELD(env, r3, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, detailMessage) = r4;
	_JC_THROW(env, r3);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_UnknownMethodSource$methods[] = {
	&_jc_soot_UnknownMethodSource$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_UnknownMethodSource$interfaces[] = {
	&_jc_soot_MethodSource$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_UnknownMethodSource$imethod_hash_bucket_2[] = {
	&_jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_UnknownMethodSource$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_UnknownMethodSource$imethod_hash_bucket_2
};

// Interface "quick" lookup hash table
static const void *_jc_soot_UnknownMethodSource$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_UnknownMethodSource$instanceof_hash_bucket_47[] = {
	&_jc_soot_MethodSource$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_UnknownMethodSource$instanceof_hash_bucket_80[] = {
	&_jc_soot_UnknownMethodSource$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_UnknownMethodSource$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_UnknownMethodSource$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[47]=	_jc_soot_UnknownMethodSource$instanceof_hash_bucket_47,
	[80]=	_jc_soot_UnknownMethodSource$instanceof_hash_bucket_80,
	[113]=	_jc_soot_UnknownMethodSource$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_UnknownMethodSource$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "soot/Body",	_JC_JLONG(0x6131d54b9700ca5d) },
	{ "soot/MethodSource",	_JC_JLONG(0x46c999f340ec4a2f) },
	{ "soot/SootMethod",	_JC_JLONG(0xbd11c16680505218) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_UnknownMethodSource$vtype _jc_soot_UnknownMethodSource$type = {
    .type= {
	.name=			"soot/UnknownMethodSource",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_UnknownMethodSource$interfaces) / sizeof(*_jc_soot_UnknownMethodSource$interfaces),
	.interfaces=		_jc_soot_UnknownMethodSource$interfaces,
	.imethod_hash_table=	_jc_soot_UnknownMethodSource$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_UnknownMethodSource$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xc2f8a579c8aaa450),
		.source_file=		"UnknownMethodSource.java",
		.instance_size=		sizeof(_jc_soot_UnknownMethodSource$refs) + sizeof(_jc_soot_UnknownMethodSource$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_UnknownMethodSource$methods) / sizeof(*_jc_soot_UnknownMethodSource$methods),
		.methods=		_jc_soot_UnknownMethodSource$methods,
		.instanceof_hash_table=	_jc_soot_UnknownMethodSource$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_UnknownMethodSource$class_depends) / sizeof(*_jc_soot_UnknownMethodSource$class_depends),
		.class_depends=		_jc_soot_UnknownMethodSource$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_UnknownMethodSource= {
	    .getBody$01a871f1d690f082=
		&_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/UnknownMethodSource.c <==
// public class soot.UnknownMethodSource

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 46c999f340ec4a2f soot_MethodSource
// @dep_class bd11c16680505218 soot_SootMethod
// @dep_class c2f8a579c8aaa450 soot_UnknownMethodSource

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_RuntimeException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable
// @dep_header soot_Body
// @dep_header soot_MethodSource
// @dep_header soot_SootMethod
// @dep_header soot_UnknownMethodSource

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/RuntimeException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"
#include "soot/Body.h"
#include "soot/MethodSource.h"
#include "soot/SootMethod.h"
#include "soot/UnknownMethodSource.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_soot_UnknownMethodSource$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_UnknownMethodSource$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_UnknownMethodSource$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_UnknownMethodSource$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_UnknownMethodSource$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_soot_UnknownMethodSource$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_UnknownMethodSource$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_UnknownMethodSource, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_UnknownMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_UnknownMethodSource$object *this)
{
	struct _jc_soot_UnknownMethodSource$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(41);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.Body getBody(soot.SootMethod, java.lang.String)
//

static _jc_linenum _jc_soot_UnknownMethodSource$linenum_table$getBody$01a871f1d690f082[];

static const unsigned char _jc_soot_UnknownMethodSource$param_ptypes$getBody$01a871f1d690f082[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_UnknownMethodSource$param_types$getBody$01a871f1d690f082[] = {
	&_jc_soot_SootMethod$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082 = {
	.name=			"getBody",
	.signature=		"(Lsoot/SootMethod;Ljava/lang/String;)Lsoot/Body;",
	.class=			&_jc_soot_UnknownMethodSource$type,
	.param_types=		&_jc_soot_UnknownMethodSource$param_types$getBody$01a871f1d690f082,
	.return_type=		&_jc_soot_Body$type,
	.param_ptypes=		&_jc_soot_UnknownMethodSource$param_ptypes$getBody$01a871f1d690f082,
	.signature_hash=	_JC_JLONG(0x1a871f1d690f082),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_UnknownMethodSource$vtable, soot_UnknownMethodSource.getBody$01a871f1d690f082) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_UnknownMethodSource$linenum_table$getBody$01a871f1d690f082
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_UnknownMethodSource, getBody$01a871f1d690f082);

_jc_soot_Body$object * _JC_JCNI_ATTR
_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082(_jc_env *const env, _jc_soot_UnknownMethodSource$object *this, _jc_soot_SootMethod$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_soot_UnknownMethodSource$object *r0;
	struct _jc_soot_SootMethod$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_RuntimeException$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_VMThrowable$object *r6;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(51);				// 0
	r3 = _JC_NEW(env, java_lang_RuntimeException);
	r4 = _JC_STRING(env, "Can't get body for unknown source!");
	_JC_REF_FIELD(env, r3, java_lang_Throwable, cause) = r3;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r3);
	_JC_REF_FIELD(env, r3, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, detailMessage) = r4;
	_JC_THROW(env, r3);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_UnknownMethodSource$methods[] = {
	&_jc_soot_UnknownMethodSource$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_UnknownMethodSource$interfaces[] = {
	&_jc_soot_MethodSource$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_UnknownMethodSource$imethod_hash_bucket_2[] = {
	&_jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_UnknownMethodSource$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_UnknownMethodSource$imethod_hash_bucket_2
};

// Interface "quick" lookup hash table
static const void *_jc_soot_UnknownMethodSource$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_UnknownMethodSource$instanceof_hash_bucket_47[] = {
	&_jc_soot_MethodSource$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_UnknownMethodSource$instanceof_hash_bucket_80[] = {
	&_jc_soot_UnknownMethodSource$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_UnknownMethodSource$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_UnknownMethodSource$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[47]=	_jc_soot_UnknownMethodSource$instanceof_hash_bucket_47,
	[80]=	_jc_soot_UnknownMethodSource$instanceof_hash_bucket_80,
	[101]=	_jc_soot_UnknownMethodSource$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_UnknownMethodSource$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "soot/Body",	_JC_JLONG(0x6131d54b9700ca5d) },
	{ "soot/MethodSource",	_JC_JLONG(0x46c999f340ec4a2f) },
	{ "soot/SootMethod",	_JC_JLONG(0xbd11c16680505218) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_UnknownMethodSource$vtype _jc_soot_UnknownMethodSource$type = {
    .type= {
	.name=			"soot/UnknownMethodSource",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_UnknownMethodSource$interfaces) / sizeof(*_jc_soot_UnknownMethodSource$interfaces),
	.interfaces=		_jc_soot_UnknownMethodSource$interfaces,
	.imethod_hash_table=	_jc_soot_UnknownMethodSource$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_UnknownMethodSource$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xc2f8a579c8aaa450),
		.source_file=		"UnknownMethodSource.java",
		.instance_size=		sizeof(_jc_soot_UnknownMethodSource$refs) + sizeof(_jc_soot_UnknownMethodSource$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_UnknownMethodSource$methods) / sizeof(*_jc_soot_UnknownMethodSource$methods),
		.methods=		_jc_soot_UnknownMethodSource$methods,
		.instanceof_hash_table=	_jc_soot_UnknownMethodSource$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_UnknownMethodSource$class_depends) / sizeof(*_jc_soot_UnknownMethodSource$class_depends),
		.class_depends=		_jc_soot_UnknownMethodSource$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_UnknownMethodSource= {
	    .getBody$01a871f1d690f082=
		&_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082,
	},
    }
};
